import { BaseProperty } from 'adminjs';
export class Property extends BaseProperty {
    column;
    columnPosition;
    constructor(column, columnPosition = 0) {
        const path = column.name;
        super({ path });
        this.column = column;
        this.columnPosition = columnPosition;
    }
    isEditable() {
        return !this.isId();
    }
    isId() {
        return this.column.isId;
    }
    name() {
        return this.column.name;
    }
    isRequired() {
        return this.column.isRequired;
    }
    isSortable() {
        return this.type() !== 'reference';
    }
    reference() {
        if (!this.column.reference) {
            return null;
        }
        return this.column.reference.relatedModelClass?.tableName;
    }
    availableValues() {
        if (!this.column.enum?.length)
            return null;
        return this.column.enum.filter(Boolean).map((v) => String(v));
    }
    position() {
        return this.columnPosition || 0;
    }
    getRawType() {
        let types = this.column.type;
        if (!types) {
            return 'string'; // type is not defined
        }
        if (!Array.isArray(types)) {
            types = [this.column.type];
        }
        if (types.includes('object'))
            return 'mixed';
        if (types.includes('string'))
            return 'string';
        if (types.includes('boolean'))
            return 'boolean';
        if (types.includes('integer') || types.includes('number'))
            return 'number';
        return 'string';
    }
    type() {
        if (this.column.reference)
            return 'reference';
        if (this.column.format === 'date-time')
            return 'datetime';
        if (this.column.format === 'date')
            return 'date';
        return this.getRawType();
    }
    isArray() {
        return Array.isArray(this.column.type) && this.column.type.includes('array');
    }
    subProperties() {
        return this.column.subProperties ?? [];
    }
}
//# sourceMappingURL=Property.js.map